package com.xinelu.manage.service.basedruginfo.impl;

import com.xinelu.manage.domain.basedruginfo.BaseDrugInfo;
import com.xinelu.manage.mapper.basedruginfo.BaseDrugInfoMapper;
import com.xinelu.manage.service.basedruginfo.IBaseDrugInfoService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 药品库Service业务层处理
 *
 * @author xinelu
 * @date 2024-05-17
 */
@Service
public class BaseDrugInfoServiceImpl implements IBaseDrugInfoService {
    @Resource
    private BaseDrugInfoMapper baseDrugInfoMapper;

    /**
     * 查询药品库
     *
     * @param id 药品库主键
     * @return 药品库
     */
    @Override
    public BaseDrugInfo selectBaseDrugInfoById(Long id) {
        return baseDrugInfoMapper.selectBaseDrugInfoById(id);
    }

    /**
     * 查询药品库列表
     *
     * @param baseDrugInfo 药品库
     * @return 药品库
     */
    @Override
    public List<BaseDrugInfo> selectBaseDrugInfoList(BaseDrugInfo baseDrugInfo) {
        return baseDrugInfoMapper.selectBaseDrugInfoList(baseDrugInfo);
    }

    /**
     * 新增药品库
     *
     * @param baseDrugInfo 药品库
     * @return 结果
     */
    @Override
    public int insertBaseDrugInfo(BaseDrugInfo baseDrugInfo) {
        baseDrugInfo.setCreateTime(LocalDateTime.now());
        return baseDrugInfoMapper.insertBaseDrugInfo(baseDrugInfo);
    }

    /**
     * 修改药品库
     *
     * @param baseDrugInfo 药品库
     * @return 结果
     */
    @Override
    public int updateBaseDrugInfo(BaseDrugInfo baseDrugInfo) {
        baseDrugInfo.setUpdateTime(LocalDateTime.now());
        return baseDrugInfoMapper.updateBaseDrugInfo(baseDrugInfo);
    }

    /**
     * 批量删除药品库
     *
     * @param ids 需要删除的药品库主键
     * @return 结果
     */
    @Override
    public int deleteBaseDrugInfoByIds(Long[] ids) {
        return baseDrugInfoMapper.deleteBaseDrugInfoByIds(ids);
    }

    /**
     * 删除药品库信息
     *
     * @param id 药品库主键
     * @return 结果
     */
    @Override
    public int deleteBaseDrugInfoById(Long id) {
        return baseDrugInfoMapper.deleteBaseDrugInfoById(id);
    }
}
